@@ -14,11 +14,11 @@ This subpackage contains the Goddard utilities.
 #
 # Import subpackages
 #
-import astro
-#import fits
-import math
-import misc
+from . import astro
+#from . import fits
+from . import math
+from . import misc
 #
 # Set __all__
 #
-__all__ = ['GoddardException', 'astro', 'math', 'misc']
+__all__ = ['astro', 'math', 'misc']
