@@ -3,5 +3,5 @@
 """
 This subpackage corresponds to the misc directory in the Goddard utilities.
 """
-from cirrange import cirrange
-from readcol import readcol
+from .cirrange import cirrange
+from .readcol import readcol
