@@ -24,24 +24,27 @@ def sdss_flagname(flagname, flagvalue, concat=False):
 
     Examples
     --------
-    >>> pydl.pydlutils.sdss.sdss_flagname('ANCILLARY_TARGET1',2310346608843161600L)
+    >>> from pydl.pydlutils.sdss import sdss_flagname
+    >>> sdss_flagname('ANCILLARY_TARGET1',2310346608843161600) # doctest: +REMOTE_DATA
     ['BRIGHTGAL', 'BLAZGX', 'ELG']
     """
     from . import maskbits
+    if maskbits is None:
+        from .set_maskbits import set_maskbits
+        maskbits = set_maskbits()
     flagu = flagname.upper()
-    bitpos = 0
+    bits = list()
+    for bit in range(64):
+        if (flagvalue & (1 << bit)) != 0:
+            bits.append(bit)
     retval = list()
-    while flagvalue > 0:
-        bit = flagvalue % 2
-        if bit > 0:
-            try:
-                f = filter(lambda x: x[1] == bitpos,maskbits[flagu].items())
-            except KeyError:
-                raise KeyError("Unknown flag group {0}!".format(flagu))
-            if len(f) > 0:
-                retval.append(f[0][0])
-        flagvalue >>= 1
-        bitpos += 1
+    for bit in bits:
+        try:
+            f = [ x for x in maskbits[flagu].items() if x[1] == bit ]
+        except KeyError:
+            raise KeyError("Unknown flag group {0}!".format(flagu))
+        if f:
+            retval.append(f[0][0])
     if concat:
         retval = ' '.join(retval)
     return retval
